#
# spec file for package cutterff
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cutterff
Summary:        Video cutter that uses FFmpeg and GTK+
Version:        0.8
Release:        lp152.2.7
Url:            https://cutterff.sourceforge.io/
Source0:        %{name}-%{version}-src.tar.bz2
Source1:        %{name}.desktop
License:        GPL-3.0
Group:          Productivity/Multimedia/Video/Editors and Convertors
Recommends:     %{name}-lang = %{version}-%{release}
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)

%description
CutterFF is a program for cutting videos using FFmpeg and GTK+.
It does not decode/encode the streams, it only copies them.

Features
 - Selecting which streams written to the output
 - Selecting the format and bitstream filters
 - Choose a program if video contains more than one
 - Set cutpoints everywhere in the video
 - Many formats and codecs supported by FFmpeg
 - Log window for displaying FFmpeg messages

%lang_package

%prep
%setup -q -n %{name}-%{version}

%build
export CPPFLAGS="%{optflags}"
%configure
make %{?_smp_mflags}

%install
%make_install
install -D -m644 %{name}.xpm %{buildroot}%{_datadir}/pixmaps/%{name}.xpm
install -D -m644 %{S:1} %{buildroot}%{_datadir}/applications/%{name}.desktop

%find_lang %{name}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%license COPYING
%doc README ChangeLog
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.xpm

%files lang -f %{name}.lang

%changelog
* Tue Mar 19 2019 enzokiel@kabelmail.de
- Update to version 0.8
  + gui.c
  - memory leak in 'cff_gui_init', 'logname' may not be freed.
    Fixed!
  - memory leak in 'cff_gui_save_image', 'filechooser_utf8str'
    may not be freed. Fixed!
  - max 10 extensions (file filter) can be added for the
    filechooser
  - if copying to another format the matching extension is now
    appended to the filename
  + ffmpeg.c
  - memory leak in 'cff_ffmpeg_copy_cb', 'bsf_ctx' may not be
    freed. Fixed!
  - videos could not loaded if the frames have a duration of
    zero. Fixed!
  - videos may not loaded by some muxers if the first packet is
    not a key frame. Fixed!
  - if copying to another format (especially to AVI) the
    timestamps may incorrect. Fixed!
  - 'cff_ffmpeg_get_format_names' now returns only the formats
    useable for the available streams
  - 'cff_ffmpeg_get_bitstream_filter_names' now returns only the
    filters useable for the available streams
  - 'cff_ffmpeg_get_outformat_extension' returns the extension
    for the given format
* Thu Feb  7 2019 enzokiel@kabelmail.de
- Update to version 0.7
  + gui.c
  - memory leak in 'cff_gui_save_start', 'format_names' may not
    be freed. Fixed!
  - disable menu entry File->Save if there is only one cut point,
    which is the last frame
  - image dialog for saving an image
  - disable okay-button if in the saving dialogs the entry field
    is empty
  + ffmpeg.c
  - buffer may too small for displaying all codecs or formats.
    Fixed!
  - may compute wrong display aspect ratio. Fixed!
  - new function 'cff_ffmpeg_printf_concat' (re)allocates memory
    and writing the string to it
  - log-window displays "Repeated last message n times", if the
    same message should be displayd more then two times
  - scale, encode and save an image
  - at end of copying the bitstream filters will be flushed
  - flushing the codec at end of stream may not work since the
    decode timestamps (dts) are not set. These missing values
    will now computed and saved while opening a file
  - replaced deprecated functions (FFmpeg version 4.0.2)
* Mon Jan 14 2019 enzokiel@kabelmail.de
- Update to version 0.6
  + gui.c
  - save dialog with option for shortest stream duration
  - memory leak in 'cff_gui_save_start', 'bsf_info' may not be
    freed. Fixed!
  - removed double question for overwriting an existing file
  - if copying the log-window to the clipboard it will be
    converted from UNIX to DOS (LF to CRLF)
    (MINGW and GTK-2 only)
  + ffmpeg.c
  - searching to previous frame may fail, if the current
    position is near the last frame and K/I/P-frame is requested.
    Fixed!
  - if at label '_got_picture' the condition 'last_frame != NULL'
    is true, the assignment 'video->vframe.packet[0].pos = -1'
    may overwrite the packet position which was found. Fixed!
  - searching one frame forward or backward may skip a frame with
    a duration less than the picture duration. Fixed!
  - the written file may too short if the duration of either
    audio or video is shorter than the other stream.
    The option 'shortest' was always active, now the user may
    choose if this should happen.
  - may hang if clicking twice on the slider at the same
    position. Fixed!
  - tiny memory leak in 'cff_ffmpeg_get_frame_dts'. Fixed!
  - flushing the codec at end of stream
* Tue Nov 27 2018 enzokiel@kabelmail.de
- Update to version 0.5
  + gui.c
  - memory leak  in 'cff_gui_logwindow_cb'. Fixed!
  - now it is possible to close the log-window while opening a
    video file as long as the progressbar is not visible
  - using an extra thread for opening a video file while the
    progressbar is not visible, which speeds up displaying
    FFmpeg messages in the log-window
  - mutex for the progress-bar
  + ffmpeg.c
  - adding a semaphore if closing the log-window while logging
    is active
  - searching the last frame may fail, if K/I/P-frame is
    requested. Fixed!
  - copying a file do not clear the dirty flag for the cutlist
  + macros-gtk.h
  - 'GuiRecMutex' to 'GuiMutex'
* Tue Oct  2 2018 enzokiel@kabelmail.de
- Update to version 0.4.2
  + gui.c
  - since GTK+ version 3.22.30 the window will not be proper
    drawn after start, but when changing the size of the window
    everything works fine. Testing the cairo surface pointer in
    the redraw functions and create a surface if the pointer is
    NULL fix this bug!
  - removed depricated functions 'gtk_color_button_get_rgb' and
    'gtk_scrolled_window_add_with_viewport', since the required
    GTK+ version is min 3.10. (GTK-3 only)
  + ffmpeg.c
  - works with FFmpeg version 4.0.2.
* Thu Jul 26 2018 jengelh@inai.de
- Use noun phrase in summary, and ensure neutrality of description.
* Thu Jul 19 2018 enzokiel@kabelmail.de
- Enable %%desktop_database_post{un} only for suse_version < 1500.
* Fri Jul 13 2018 enzokiel@kabelmail.de
- Initial package, version 0.4.1
